# ps6000a Reference
## Initializing ps6000a
```
import pypicosdk as psdk

scope = psdk.ps6000a()

scope.open_unit()
# Do something
scope.close_unit()
```

## Reference
::: pypicosdk.pypicosdk.ps6000a
    options:
        filters:
        - "!.*_to_.*"
        - "!^_[^_]"
        show_root_toc_entry: false
        summary: true